# WhoIsHome
#### A simple Python CLI dashboard which uses <a href="https://nmap.org/">nmap</a> to help you keep track of who's on your network (made beautiful with the python library <a href="https://github.com/willmcgugan/rich">rich</a>).

<br>

1. Install nmap.

2. Install using pip: 
`pip install whoishome`

3. Add MAC addresses: `whoishome --add Jack=DE:FA:CE:D1:23:45`

4. Learn more about how to use it: `whoishome --help`

5. Run it: `whoishome --subnet 192.168.0.1/24`

<img src="https://raw.githubusercontent.com/jackeown/whoIsHome/main/screenshot.jpg">